@@ -1,45 +1,68 @@
+#' \pkg{knitrBootstrap} A framework to create Bootstrap 3 HTML reports from knitr
+#'   Rmarkdown and RHTML.
+#' See \code{\link{knit_bootstrap}} for the common usage.
+#' If you are using RStudio, see the second example
+#' @examples
+#' \dontrun{
+#' #defaults only
+#' knit_bootstrap('file.Rmd')
+#' #Rstudio
+#' #you also have to put render_html() in your rmd setup file, then use the
+#' below code and the knit button 
+#' options(rstudio.markdownToHTML =
+#'  function(inputFile, outputFile) {
+#'    require(knitrBootstrap)
+#'    knit_bootstrap_md(input=inputFile, output=outputFile)
+#'  }
+#' )
+#' }
+#' @import knitr markdown
+#' @name primerTree
+#' @docType package
+NULL
+
 boot_styles = c(
-  'default'='http://netdna.bootstrapcdn.com/bootstrap/3.0.0/css/bootstrap.min.css',
-  'amelia'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/amelia/bootstrap.min.css',
-  'cerulean'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/cerulean/bootstrap.min.css',
-  'cosmo'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/cosmo/bootstrap.min.css',
-  'cyborg'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/cyborg/bootstrap.min.css',
-  'journal'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/journal/bootstrap.min.css',
-  'flatly'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/flatly/bootstrap.min.css',
-  'readable'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/readable/bootstrap.min.css',
-  'simplex'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/simplex/bootstrap.min.css',
-  'slate'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/slate/bootstrap.min.css',
-  'spacelab'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/spacelab/bootstrap.min.css',
-  'united'='http://netdna.bootstrapcdn.com/bootswatch/3.0.0/united/bootstrap.min.css'
+  'default'='https://netdna.bootstrapcdn.com/bootstrap/3.0.0/css/bootstrap.min.css',
+  'amelia'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/amelia/bootstrap.min.css',
+  'cerulean'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/cerulean/bootstrap.min.css',
+  'cosmo'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/cosmo/bootstrap.min.css',
+  'cyborg'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/cyborg/bootstrap.min.css',
+  'journal'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/journal/bootstrap.min.css',
+  'flatly'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/flatly/bootstrap.min.css',
+  'readable'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/readable/bootstrap.min.css',
+  'simplex'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/simplex/bootstrap.min.css',
+  'slate'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/slate/bootstrap.min.css',
+  'spacelab'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/spacelab/bootstrap.min.css',
+  'united'='https://netdna.bootstrapcdn.com/bootswatch/3.0.0/united/bootstrap.min.css'
 )
 
 code_styles = c(
-  'default'='http://yandex.st/highlightjs/7.3/styles/default.min.css',
-  'dark'='http://yandex.st/highlightjs/7.3/styles/dark.min.css',
-  'far'='http://yandex.st/highlightjs/7.3/styles/far.min.css',
-  'idea'='http://yandex.st/highlightjs/7.3/styles/idea.min.css',
-  'sunburst'='http://yandex.st/highlightjs/7.3/styles/sunburst.min.css',
-  'zenburn'='http://yandex.st/highlightjs/7.3/styles/zenburn.min.css',
-  'visual studio'='http://yandex.st/highlightjs/7.3/styles/vs.min.css',
-  'ascetic'='http://yandex.st/highlightjs/7.3/styles/ascetic.min.css',
-  'magula'='http://yandex.st/highlightjs/7.3/styles/magula.min.css',
-  'github'='http://yandex.st/highlightjs/7.3/styles/github.min.css',
-  'google code'='http://yandex.st/highlightjs/7.3/styles/googlecode.min.css',
-  'brown paper'='http://yandex.st/highlightjs/7.3/styles/brown_paper.min.css',
-  'school book'='http://yandex.st/highlightjs/7.3/styles/school_book.min.css',
-  'ir black'='http://yandex.st/highlightjs/7.3/styles/ir_black.min.css',
-  'solarized - dark'='http://yandex.st/highlightjs/7.3/styles/solarized_dark.min.css',
-  'solarized - light'='http://yandex.st/highlightjs/7.3/styles/solarized_light.min.css',
-  'arta'='http://yandex.st/highlightjs/7.3/styles/arta.min.css',
-  'monokai'='http://yandex.st/highlightjs/7.3/styles/monokai.min.css',
-  'xcode'='http://yandex.st/highlightjs/7.3/styles/xcode.min.css',
-  'pojoaque'='http://yandex.st/highlightjs/7.3/styles/pojoaque.min.css',
-  'rainbow'='http://yandex.st/highlightjs/7.3/styles/rainbow.min.css',
-  'tomorrow'='http://yandex.st/highlightjs/7.3/styles/tomorrow.min.css',
-  'tomorrow night'='http://yandex.st/highlightjs/7.3/styles/tomorrow-night.min.css',
-  'tomorrow night bright'='http://yandex.st/highlightjs/7.3/styles/tomorrow-night-bright.min.css',
-  'tomorrow night blue'='http://yandex.st/highlightjs/7.3/styles/tomorrow-night-blue.min.css',
-  'tomorrow night eighties'='http://yandex.st/highlightjs/7.3/styles/tomorrow-night-eighties.min.css'
+  'default'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/default.min.css',
+  'dark'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/dark.min.css',
+  'far'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/far.min.css',
+  'idea'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/idea.min.css',
+  'sunburst'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/sunburst.min.css',
+  'zenburn'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/zenburn.min.css',
+  'visual studio'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/vs.min.css',
+  'ascetic'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/ascetic.min.css',
+  'magula'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/magula.min.css',
+  'github'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/github.min.css',
+  'google code'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/googlecode.min.css',
+  'brown paper'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/brown_paper.min.css',
+  'school book'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/school_book.min.css',
+  'ir black'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/ir_black.min.css',
+  'solarized - dark'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/solarized_dark.min.css',
+  'solarized - light'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/solarized_light.min.css',
+  'arta'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/arta.min.css',
+  'monokai'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/monokai.min.css',
+  'xcode'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/xcode.min.css',
+  'pojoaque'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/pojoaque.min.css',
+  'rainbow'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/rainbow.min.css',
+  'tomorrow'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/tomorrow.min.css',
+  'tomorrow night'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/tomorrow-night.min.css',
+  'tomorrow night bright'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/tomorrow-night-bright.min.css',
+  'tomorrow night blue'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/tomorrow-night-blue.min.css',
+  'tomorrow night eighties'='https://cdnjs.cloudflare.com/ajax/libs/highlight.js/7.3/styles/tomorrow-night-eighties.min.css'
 )
 # note this only works for links with href as the first param
 link_pattern='<link\\s+href='
@@ -265,7 +288,7 @@ create_header <-
                                               ';'), javascript)
 
   output = paste(includes,
-                 '<script>', javascript, '</script>',
+                 '<script defer="defer">', javascript, '</script>',
                  '<style>', css, '</style>',
                  boot_toggle,
                  code_toggle,
