@@ -1,9 +1,5 @@
 
-## @knitr , include=F
-library(knitr);render_html()
-
-
-## @knitr maps_arrests, dev='png', fig.show='hold', warning=FALSE
+## ----maps_arrests, dev='png', fig.show='hold', warning=FALSE-------------
 library(ggplot2)
 crimes <- data.frame(state = tolower(rownames(USArrests)), USArrests)
 library(reshape2) # for melt
